from ..common import objects_pb2 as _objects_pb2
from ..common import submitter_common_pb2 as _submitter_common_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
